PickerTui

Struct PickerTui 

pub struct PickerTui {
    pub default_query: String,
    pub header: Option<String>,
    pub auto_accept: bool,
}

Fields

default_query: String

The default value of the query text area

header: Option<String>

The header text to indicate to the user what is being chosen

auto_accept: bool

If there is zero or one options, automatically accept the choice

Implementations

Source

impl PickerTui

pub fn new() -> Self

Examples found in repository?
examples/pick_a_noun.rs (line 5)
3pub fn main() -> eyre::Result<()> {
4    let nouns = vec!["dog", "cat", "house", "pickle", "mouse"];
5    let chosen = PickerTui::new().set_header("Pick a noun").pick_one(nouns)?;
6    println!("You chose {}", chosen);
7
8    Ok(())
9}
More examples
Hide additional examples
examples/pick_many_nouns.rs (line 5)
3pub fn main() -> eyre::Result<()> {
4    let nouns = vec!["dog", "cat", "house", "pickle", "mouse"];
5    let chosen = PickerTui::new()
6        .set_header("Press tab to select entries")
7        .pick_many(nouns)?;
8
9    println!("You chose {:?}", chosen);
10
11    Ok(())
12}
examples/starting_search.rs (line 5)
3pub fn main() -> eyre::Result<()> {
4    let nouns = vec!["dog", "cat", "house", "pickle", "mouse"];
5    let chosen = PickerTui::new()
6        .set_header("Pick a noun")
7        .set_query("ouse")
8        .pick_one(nouns)?;
9    println!("You chose {}", chosen);
10
11    Ok(())
12}
examples/multiline.rs (line 11)
3pub fn main() -> eyre::Result<()> {
4    let choices = vec![
5        "First\nSecond\nThird",
6        "A\nB\nC",
7        "IMPORT BRUH\nDO THING\nWOOHOO!",
8        "single item",
9        "another single item",
10    ];
11    let chosen = PickerTui::new().pick_many(choices)?;
12    println!("You chose: {chosen:#?}");
13    Ok(())
14}
examples/pick_a_path.rs (line 12)
4pub fn main() -> eyre::Result<()> {
5    let mut choices = Vec::new();
6    let dir = std::fs::read_dir(".")?;
7    for entry in dir {
8        let entry = entry?;
9        choices.push(entry);
10    }
11
12    let chosen = PickerTui::new()
13        .set_header("Pick a path")
14        .pick_one(choices.into_iter().map(|entry| Choice {
15            key: entry.path().display().to_string(), // the value shown to the user
16            value: entry, // the inner value we want to have after the user picks
17        }))?;
18
19    println!("You chose {}", chosen.file_name().to_string_lossy());
20
21    Ok(())
22}
pub fn set_header(self, header: impl Into<String>) -> Self

Examples found in repository?
examples/pick_a_noun.rs (line 5)
3pub fn main() -> eyre::Result<()> {
4    let nouns = vec!["dog", "cat", "house", "pickle", "mouse"];
5    let chosen = PickerTui::new().set_header("Pick a noun").pick_one(nouns)?;
6    println!("You chose {}", chosen);
7
8    Ok(())
9}
More examples
Hide additional examples
examples/pick_many_nouns.rs (line 6)
3pub fn main() -> eyre::Result<()> {
4    let nouns = vec!["dog", "cat", "house", "pickle", "mouse"];
5    let chosen = PickerTui::new()
6        .set_header("Press tab to select entries")
7        .pick_many(nouns)?;
8
9    println!("You chose {:?}", chosen);
10
11    Ok(())
12}
examples/starting_search.rs (line 6)
3pub fn main() -> eyre::Result<()> {
4    let nouns = vec!["dog", "cat", "house", "pickle", "mouse"];
5    let chosen = PickerTui::new()
6        .set_header("Pick a noun")
7        .set_query("ouse")
8        .pick_one(nouns)?;
9    println!("You chose {}", chosen);
10
11    Ok(())
12}
examples/pick_a_path.rs (line 13)
4pub fn main() -> eyre::Result<()> {
5    let mut choices = Vec::new();
6    let dir = std::fs::read_dir(".")?;
7    for entry in dir {
8        let entry = entry?;
9        choices.push(entry);
10    }
11
12    let chosen = PickerTui::new()
13        .set_header("Pick a path")
14        .pick_one(choices.into_iter().map(|entry| Choice {
15            key: entry.path().display().to_string(), // the value shown to the user
16            value: entry, // the inner value we want to have after the user picks
17        }))?;
18
19    println!("You chose {}", chosen.file_name().to_string_lossy());
20
21    Ok(())
22}
pub fn set_auto_accept(self, auto_accept: bool) -> Self

pub fn set_query(self, query: impl Into<String>) -> Self

Examples found in repository?
examples/starting_search.rs (line 7)
3pub fn main() -> eyre::Result<()> {
4    let nouns = vec!["dog", "cat", "house", "pickle", "mouse"];
5    let chosen = PickerTui::new()
6        .set_header("Pick a noun")
7        .set_query("ouse")
8        .pick_one(nouns)?;
9    println!("You chose {}", chosen);
10
11    Ok(())
12}
pub fn pick_one<T>(&self, choices: impl IntoChoices<T>) -> PickResult<T>

Examples found in repository?
examples/pick_a_noun.rs (line 5)
3pub fn main() -> eyre::Result<()> {
4    let nouns = vec!["dog", "cat", "house", "pickle", "mouse"];
5    let chosen = PickerTui::new().set_header("Pick a noun").pick_one(nouns)?;
6    println!("You chose {}", chosen);
7
8    Ok(())
9}
More examples
Hide additional examples
examples/starting_search.rs (line 8)
3pub fn main() -> eyre::Result<()> {
4    let nouns = vec!["dog", "cat", "house", "pickle", "mouse"];
5    let chosen = PickerTui::new()
6        .set_header("Pick a noun")
7        .set_query("ouse")
8        .pick_one(nouns)?;
9    println!("You chose {}", chosen);
10
11    Ok(())
12}
examples/pick_a_path.rs (lines 14-17)
4pub fn main() -> eyre::Result<()> {
5    let mut choices = Vec::new();
6    let dir = std::fs::read_dir(".")?;
7    for entry in dir {
8        let entry = entry?;
9        choices.push(entry);
10    }
11
12    let chosen = PickerTui::new()
13        .set_header("Pick a path")
14        .pick_one(choices.into_iter().map(|entry| Choice {
15            key: entry.path().display().to_string(), // the value shown to the user
16            value: entry, // the inner value we want to have after the user picks
17        }))?;
18
19    println!("You chose {}", chosen.file_name().to_string_lossy());
20
21    Ok(())
22}
pub fn pick_many<T>(&self, choices: impl IntoChoices<T>) -> PickResult<Vec<T>>

Examples found in repository?
examples/pick_many_nouns.rs (line 7)
3pub fn main() -> eyre::Result<()> {
4    let nouns = vec!["dog", "cat", "house", "pickle", "mouse"];
5    let chosen = PickerTui::new()
6        .set_header("Press tab to select entries")
7        .pick_many(nouns)?;
8
9    println!("You chose {:?}", chosen);
10
11    Ok(())
12}
More examples
Hide additional examples
examples/multiline.rs (line 11)
3pub fn main() -> eyre::Result<()> {
4    let choices = vec![
5        "First\nSecond\nThird",
6        "A\nB\nC",
7        "IMPORT BRUH\nDO THING\nWOOHOO!",
8        "single item",
9        "another single item",
10    ];
11    let chosen = PickerTui::new().pick_many(choices)?;
12    println!("You chose: {chosen:#?}");
13    Ok(())
14}
pub async fn pick_one_reloadable<T, F, C>( &self, choice_supplier: F, ) -> PickResult<T>
where F: AsyncFn(bool) -> Result<C>, C: IntoChoices<T>,

pub async fn pick_many_reloadable<T, F, C>( &self, choice_supplier: F, ) -> PickResult<Vec<T>>
where F: AsyncFn(bool) -> Result<C>, C: IntoChoices<T>,

pub async fn pick_inner_reloadable<T, F, C>( &self, many: bool, choice_supplier: F, ) -> PickResult<Vec<T>>
where F: AsyncFn(bool) -> Result<C>, C: IntoChoices<T>,

pub fn pick_inner<T>( &self, many: bool, choices: impl IntoChoices<T>, ) -> PickResult<Vec<T>>